texlive[74324] trunk: luaotfload (27feb25)

commits+karl at tug.org commits+karl at tug.org
Thu Feb 27 21:11:39 CET 2025


Revision: 74324
          https://tug.org/svn/texlive?view=revision&revision=74324
Author:   karl
Date:     2025-02-27 21:11:38 +0100 (Thu, 27 Feb 2025)
Log Message:
-----------
luaotfload (27feb25)

Modified Paths:
--------------
    trunk/Build/source/texk/texlive/linked_scripts/luaotfload/luaotfload-tool.lua
    trunk/Master/texmf-dist/doc/luatex/luaotfload/NEWS
    trunk/Master/texmf-dist/doc/luatex/luaotfload/README.md
    trunk/Master/texmf-dist/doc/luatex/luaotfload/filegraph.pdf
    trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload-conf.pdf
    trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload-latex.pdf
    trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload-main.tex
    trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload-tool.pdf
    trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload-tool.rst
    trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload.conf.rst
    trunk/Master/texmf-dist/doc/luatex/luaotfload/scripts-demo.pdf
    trunk/Master/texmf-dist/doc/luatex/luaotfload/shaper-demo-graphite.pdf
    trunk/Master/texmf-dist/doc/luatex/luaotfload/shaper-demo.pdf
    trunk/Master/texmf-dist/doc/man/man1/luaotfload-tool.1
    trunk/Master/texmf-dist/doc/man/man1/luaotfload-tool.man1.pdf
    trunk/Master/texmf-dist/doc/man/man5/luaotfload.conf.5
    trunk/Master/texmf-dist/doc/man/man5/luaotfload.conf.man5.pdf
    trunk/Master/texmf-dist/scripts/luaotfload/luaotfload-tool.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-arabic.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-auxiliary.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-bcp47.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-colors.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-configuration.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-database.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-diagnostics.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-dvi.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-embolden.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-fallback.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-features.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-filelist.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-glyphlist.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-define.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-plug.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-var-cff2.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-var-t2-writer.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-var-ttf.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-init.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-letterspace.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-loaders.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-log.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-multiscript.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-notdef.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-parsers.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-resolvers.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-scripts.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-status.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-suppress.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-szss.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-tounicode.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-unicode.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload.lua
    trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload.sty

Modified: trunk/Build/source/texk/texlive/linked_scripts/luaotfload/luaotfload-tool.lua
===================================================================
--- trunk/Build/source/texk/texlive/linked_scripts/luaotfload/luaotfload-tool.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Build/source/texk/texlive/linked_scripts/luaotfload/luaotfload-tool.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -9,8 +9,8 @@
 
 local ProvidesLuaModule = { 
     name          = "luaotfload-tool",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload-tool / database functionality",
     license       = "GPL v2.0"
 }
@@ -336,7 +336,7 @@
 
     local runtime = luaotfload.runtime
     local notes   = config.luaotfload.status
-    local notes   = status and status.notes or { }
+    local notes   = notes and notes.notes or { }
 
     out (about, luaotfload.self)
     out ("%s version: %q", luaotfload.self, version)

Modified: trunk/Master/texmf-dist/doc/luatex/luaotfload/NEWS
===================================================================
--- trunk/Master/texmf-dist/doc/luatex/luaotfload/NEWS	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/doc/luatex/luaotfload/NEWS	2025-02-27 20:11:38 UTC (rev 74324)
@@ -1,5 +1,12 @@
 Change History
 --------------
+2024-12-03 luaotfload v3.29
+
+    *  Preserve subtypes while letterspacing.
+    *  Improve logging for auxiliary functions.
+    *  Improve cache path selection when parts of cache path are not writable.
+    *  Fix broken luaotfload-tool.
+
 2024-02-28 luaotfload v3.28
 
     *  Improving compatibility with Windows paths
@@ -24,7 +31,7 @@
        precedence.
     *  Support xdvipsk in DVI mode
     *  Preserve soft-hyphens when dropping default ignorable characters
-    *  Hash cache keys to better support certain rather unflexible operating
+    *  Hash cache keys to better support certain rather inflexible operating
        systems
     *  Various bug fixes
 
@@ -159,7 +166,7 @@
 2019-11-04 luaotfload v3.1
     * added code to use the harfbuzz library of luahbtex ("mode=harf")
     * fonts in ttc can now be indexed by name
-    * remove a number of lua tables from the global enviroment (_G) to reduce the polution. 
+    * remove a number of lua tables from the global environment (_G) to reduce the pollution. 
       Kept there are only the tables luaotfload, fonts and nodes.
     * sync with context files from 2019-10-29
 
@@ -253,7 +260,7 @@
     * Add ``--dumpconf`` option to luaotfload-tool for generating configuration
       files.
     * Move fontloader files to subtree src/fontloader.
-    * New script ``mkimport`` facilitates maintainance of code imported from
+    * New script ``mkimport`` facilitates maintenance of code imported from
       Context.
     * Revised letterspacing, now utilizing the ``node.direct`` interface.
     * Revized colorization of fonts, utilizing ``node.direct`` (Dohyun Kim).
@@ -333,7 +340,7 @@
       backward-incompatible changes in the font structure. A
       backward-compatibility layer has been added for the current
       versions of fontspec, unicode-math and microtype, but it should
-      disapear in a future version.
+      disappear in a future version.
     * Synchronisation with ConTeXt is now easier and can be done by just
       updating luaotfload-merged.lua (<= luatex-fonts-merged.lua from
       the LuaTeX-Plain format)
@@ -372,7 +379,7 @@
 2013/04/11, luaotfload v1.28:
     * Adapting to LuaTeX 0.75
     * Fix small documentation issues in mkluatexfontdb
-    * Fix possible infite loop with fontconfig config files references
+    * Fix possible infinite loop with fontconfig config files references
     * Adding semibold synonym for bold
     * file:xxx syntax now uses the same search function as name: which
       make more fonts recognized
@@ -475,7 +482,7 @@
 
 2010/05/28, luaotfload v1.08:
     * fix misc. bugs with system fonts scanning
-    * parse fontconfig configuration directly, no longer dependant on 'fc-list'
+    * parse fontconfig configuration directly, no longer dependent on 'fc-list'
     * now if no font names database is found, luaotfload will generate it, also
       it will force an update of the database if the asked font can not be
       found

Modified: trunk/Master/texmf-dist/doc/luatex/luaotfload/README.md
===================================================================
--- trunk/Master/texmf-dist/doc/luatex/luaotfload/README.md	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/doc/luatex/luaotfload/README.md	2025-02-27 20:11:38 UTC (rev 74324)
@@ -1,8 +1,8 @@
 # The Luaotfload Package
 
-VERSION: 3.28
+VERSION: 3.29
 
-DATE: 2024-02-14
+DATE: 2024-12-03
 
 
 ## Description

Modified: trunk/Master/texmf-dist/doc/luatex/luaotfload/filegraph.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload-conf.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload-latex.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload-main.tex
===================================================================
--- trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload-main.tex	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload-main.tex	2025-02-27 20:11:38 UTC (rev 74324)
@@ -32,7 +32,7 @@
 \beginfrontmatter
 
   \setdocumenttitle  {The \identifier{luaotfload} package}
-  \setdocumentdate   {2024-02-14 v3.28}
+  \setdocumentdate   {2024-12-03 v3.29}
   \setdocumentauthor {LaTeX3 Project\\
                       Elie Roux · Khaled Hosny · Philipp Gesang · Ulrike Fischer · Marcel Krüger\\
                       Home: \hyperlink {https://github.com/latex3/luaotfload}}
@@ -62,6 +62,15 @@
 \endsection
 
 \beginsection{Changes}
+\beginsubsection{New in version 3.29}
+\begin{itemize}
+  \item Preserve subtypes while letterspacing.
+  \item Improve logging for auxiliary functions.
+  \item Improve cache path selection when parts of cache path are not writable.
+  \item Fix broken luaotfload-tool.
+\end{itemize}
+\endsubsection
+
 \beginsubsection{New in version 3.28}
 \begin{itemize}
   \item Improving compatibility with Windows paths
@@ -74,7 +83,7 @@
     precedence.
   \item Support xdvipsk in DVI mode
   \item Preserve soft-hyphens when dropping default ignorable characters
-  \item Hash cache keys to better support certain rather unflexible operating
+  \item Hash cache keys to better support certain rather inflexible operating
     systems
   \item Various bug fixes
 \end{itemize}
@@ -239,7 +248,7 @@
         officially by the LaTeX3 Project team.
 \item   Code to use the harfbuzz library of luahbtex has been added. See the description of the harf mode.
 \item   fonts in ttc-collections can now be indexed by name.
-\item   To reduce the polution of the global lua enviroment a number of lua tables have been removed.
+\item   To reduce the pollution of the global lua environment a number of lua tables have been removed.
         Only the tables \identifier{luaotfload}, \identifier{fonts} and \identifier{nodes} have been kept there.
 \item   The fontloader has been synched with the context files from 2019-10-29.
 
@@ -346,7 +355,7 @@
   \beginaltitem {Lualibs} The update of the fontloader files also required an update of the \identifier{Lualibs} package. This \identifier{Luaotfload} version needs version 2.6 of \identifier{Lualibs}.
   \endaltitem
 
-  \beginaltitem {Maintenance} As the current maintainer wasn't available and it was urgent to get a \identifier{Luaotfload} compatible with \LuaTeX\ 1.08/1.09 maintenance has been transfered to Ulrike Fischer and Marcel Krüger. The package was maintained and developed at \hyperlink{https://github.com/u-fischer/luaotfload}.
+  \beginaltitem {Maintenance} As the current maintainer wasn't available and it was urgent to get a \identifier{Luaotfload} compatible with \LuaTeX\ 1.08/1.09 maintenance has been transferred to Ulrike Fischer and Marcel Krüger. The package was maintained and developed at \hyperlink{https://github.com/u-fischer/luaotfload}.
   \endaltitem
 
   \beginaltitem {Documentation}
@@ -409,7 +418,7 @@
 
 \identifier{Luaotfload} is part of \hologo{LuaLaTeX}, the community-driven
 project to provide a foundation for using the \LaTeX\ format with the
-full capabilites of the \LuaTeX\ engine.
+full capabilities of the \LuaTeX\ engine.
 %
 As such, the distinction between end users, contributors, and project
 maintainers is intentionally kept less strict, lest we unduly
@@ -696,7 +705,7 @@
 Lastly, if none of the above succeeded, attempt to resolve the request as a
 \inlinecode {name:} lookup by searching the font index for \meta{font name}.
 %
-The behavior of this “anonymous” lookup is configurable, see the configuation
+The behavior of this “anonymous” lookup is configurable, see the configuration
 manpage for details.
 
 Furthermore, \identifier{luaotfload} supports the slashed (shorthand)
@@ -1023,7 +1032,7 @@
 
           The keys in such a table are like above RGB colors with an optional transparency setting.
           The values are either lists of glyph names or GID numbers.
-          Both types are font dependant! Not every font use the same
+          Both types are font dependent! Not every font use the same
           glyph names (or even glyph names at all). GID number are font specific anyway. The GID can be found
           by looking up the \verb+["index"]+ entry in the lua file of a font.
 
@@ -1045,9 +1054,10 @@
 
 
   \beginaltitem {axis\&instance}
-    Experimental!\marginpar{\mbox{}\hfill NEW in v3.15!} Support for \OpenType\ variable fonts. \emph{Varible fonts are only
-    supported in \texttt{base} and \texttt{node} mode, not in \texttt{harf}
-    mode.}
+    Experimental!\marginpar{\mbox{}\hfill NEW in v3.15!} Support for \OpenType\
+    variable fonts. \emph{Variable fonts use very different implementations in
+      \texttt{harf} compared to \texttt{base} and \texttt{node} mode, so in
+      case of unexpected behavior it can make sense to try the other mode.}
 
     To specify the parameters of a variable font, you can either specify a
     predefined instance of the font by passing the associated
@@ -1565,7 +1575,7 @@
 
 For example, the \identifier{Latin Modern} family of fonts does, as indicated
 in the name, not provide Cyrillic glyphs. If Latin script dominates in the copy
-with interspersed Cyrillic, a fallback can be created from a similiar looking
+with interspersed Cyrillic, a fallback can be created from a similar looking
 font like \identifier{Computer Modern Unicode}, taking advantage of the fact
 that it too derives from Knuth’s original \identifier{Computer Modern} series:
 
@@ -2511,7 +2521,7 @@
 
 When these functions aren't used, then the color is set based on colorstack 0.
 By default a new colorstack is allocated for transparency, but alternatively an
-existsing colorstack for this prpose can be set:
+existing colorstack for this purpose can be set:
 
 \beginfunctionlist
 

Modified: trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload-tool.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload-tool.rst
===================================================================
--- trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload-tool.rst	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload-tool.rst	2025-02-27 20:11:38 UTC (rev 74324)
@@ -6,9 +6,9 @@
          generate and query the Luaotfload font names database
 -----------------------------------------------------------------------
 
-:Date:                  2024-02-14
+:Date:                  2024-12-03
 :Copyright:             GPL v2.0
-:Version:               3.28
+:Version:               3.29
 :Manual section:        1
 :Manual group:          text processing
 

Modified: trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload.conf.rst
===================================================================
--- trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload.conf.rst	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/doc/luatex/luaotfload/luaotfload.conf.rst	2025-02-27 20:11:38 UTC (rev 74324)
@@ -6,9 +6,9 @@
                      Luaotfload configuration file
 -----------------------------------------------------------------------
 
-:Date:                  2024-02-14
+:Date:                  2024-12-03
 :Copyright:             GPL v2.0
-:Version:               3.28
+:Version:               3.29
 :Manual section:        5
 :Manual group:          text processing
 

Modified: trunk/Master/texmf-dist/doc/luatex/luaotfload/scripts-demo.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/doc/luatex/luaotfload/shaper-demo-graphite.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/doc/luatex/luaotfload/shaper-demo.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/doc/man/man1/luaotfload-tool.1
===================================================================
--- trunk/Master/texmf-dist/doc/man/man1/luaotfload-tool.1	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/doc/man/man1/luaotfload-tool.1	2025-02-27 20:11:38 UTC (rev 74324)
@@ -27,7 +27,7 @@
 .\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
 .in \\n[rst2man-indent\\n[rst2man-indent-level]]u
 ..
-.TH "LUAOTFLOAD-TOOL" 1 "2024-02-14" "3.28" "text processing"
+.TH "LUAOTFLOAD-TOOL" 1 "2024-12-03" "3.29" "text processing"
 .SH NAME
 luaotfload-tool \- generate and query the Luaotfload font names database
 .SH SYNOPSIS

Modified: trunk/Master/texmf-dist/doc/man/man1/luaotfload-tool.man1.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/doc/man/man5/luaotfload.conf.5
===================================================================
--- trunk/Master/texmf-dist/doc/man/man5/luaotfload.conf.5	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/doc/man/man5/luaotfload.conf.5	2025-02-27 20:11:38 UTC (rev 74324)
@@ -27,7 +27,7 @@
 .\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
 .in \\n[rst2man-indent\\n[rst2man-indent-level]]u
 ..
-.TH "LUAOTFLOAD.CONF" 5 "2024-02-14" "3.28" "text processing"
+.TH "LUAOTFLOAD.CONF" 5 "2024-12-03" "3.29" "text processing"
 .SH NAME
 luaotfload.conf \- Luaotfload configuration file
 .SH SYNOPSIS

Modified: trunk/Master/texmf-dist/doc/man/man5/luaotfload.conf.man5.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/scripts/luaotfload/luaotfload-tool.lua
===================================================================
--- trunk/Master/texmf-dist/scripts/luaotfload/luaotfload-tool.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/scripts/luaotfload/luaotfload-tool.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -9,8 +9,8 @@
 
 local ProvidesLuaModule = { 
     name          = "luaotfload-tool",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload-tool / database functionality",
     license       = "GPL v2.0"
 }
@@ -336,7 +336,7 @@
 
     local runtime = luaotfload.runtime
     local notes   = config.luaotfload.status
-    local notes   = status and status.notes or { }
+    local notes   = notes and notes.notes or { }
 
     out (about, luaotfload.self)
     out ("%s version: %q", luaotfload.self, version)

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-arabic.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-arabic.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-arabic.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-arabic",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / features",
     license       = "GPL v2.0",
     author        = "Marcel Krüger",

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-auxiliary.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-auxiliary.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-auxiliary.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -6,8 +6,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") {
     name          = "luaotfload-auxiliary",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / auxiliary functions",
     license       = "GPL v2.0"
 }
@@ -486,6 +486,7 @@
     end
     return false
   else
+    local fontname = tfmdata.fontname
     local features = get_features (tfmdata)
     if features == false then
       logreport ("log", 1, "aux", "font no %d lacks a features table", font_id)
@@ -495,7 +496,7 @@
       --- where method: "gpos" | "gsub"
       for feature, data in next, featuredata do
         if data[asked_script] then
-          logreport ("log", 1, "aux",
+          logreport ("log", 2, "aux",
                      "font no %d (%s) defines feature %s for script %s",
                      font_id, fontname, feature, asked_script)
           return true
@@ -502,7 +503,7 @@
         end
       end
     end
-    logreport ("log", 0, "aux",
+    logreport ("log", 2, "aux",
                "font no %d (%s) defines no feature for script %s",
                font_id, fontname, asked_script)
   end
@@ -556,6 +557,7 @@
     asked_language  = stringlower(asked_language)
     local tfmdata = identifiers[font_id]
     if not tfmdata then return false end
+    local fontname = tfmdata.fontname
     local features = get_features (tfmdata)
     if features == false then
       logreport ("log", 1, "aux", "font no %d lacks a features table", font_id)
@@ -566,7 +568,7 @@
       for feature, data in next, featuredata do
         local scriptdata = data[asked_script]
         if scriptdata and scriptdata[asked_language] then
-          logreport ("log", 1, "aux",
+          logreport ("log", 2, "aux",
                      "font no %d (%s) defines feature %s "
                      .. "for script %s with language %s",
                      font_id, fontname, feature,
@@ -575,7 +577,7 @@
         end
       end
     end
-    logreport ("log", 0, "aux",
+    logreport ("log", 2, "aux",
                "font no %d (%s) defines no feature "
                .. "for script %s with language %s",
                font_id, fontname, asked_script, asked_language)
@@ -584,7 +586,7 @@
 end
 
 --[[doc--
-A function to check if a font is a variabe font with a given axis.
+A function to check if a font is a variable font with a given axis.
 --doc]]--
 
 function aux.provides_axis(font_id, asked_axis)
@@ -712,6 +714,7 @@
     end
     return false
   else
+    local fontname = tfmdata.fontname
     asked_language  = stringlower(asked_language)
     local features = get_features (tfmdata)
     if features == false then
@@ -724,7 +727,7 @@
       if feature then
         local scriptdata = feature[asked_script]
         if scriptdata and scriptdata[asked_language] then
-          logreport ("log", 1, "aux",
+          logreport ("log", 2, "aux",
                      "font no %d (%s) defines feature %s "
                      .. "for script %s with language %s",
                      font_id, fontname, asked_feature,
@@ -733,7 +736,7 @@
         end
       end
     end
-    logreport ("log", 0, "aux",
+    logreport ("log", 2, "aux",
                "font no %d (%s) does not define feature %s for script %s with language %s",
                font_id, fontname, asked_feature, asked_script, asked_language)
   end

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-bcp47.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-bcp47.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-bcp47.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -1,4 +1,4 @@
--- Suport for parsing BCP47 based language tags into components
+-- Support for parsing BCP47 based language tags into components
 local normalize_case, language_tag do
   local l = lpeg or require'lpeg'
   local function rep(base, num, max)

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-colors.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-colors.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-colors.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-colors",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / color",
     license       = "GPL v2.0",
     author        = "Khaled Hosny, Elie Roux, Philipp Gesang, Dohyun Kim, David Carlisle",
@@ -155,7 +155,7 @@
 end
 
 local color_stack = 0
--- Beside maybe allowing {transpareny} package compatibility at some
+-- Beside maybe allowing {transparency} package compatibility at some
 -- point, this ensures that the stack is only created if it is actually
 -- needed. Especially important because it adds /TransGs1 gs to every page
 local function transparent_stack()

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-configuration.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-configuration.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-configuration.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -7,8 +7,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-configuration",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / config file reader",
     license       = "GPL v2.0"
 }
@@ -224,7 +224,8 @@
     log_level          = 0,
     color_callback     = "post_linebreak_filter",
     fontloader         = default_fontloader (),
-    default_dvi_driver = "dvisvgm"
+    default_dvi_driver = "dvisvgm",
+    live               = true,
   },
   misc = {
     bisect         = false,
@@ -270,6 +271,7 @@
 
     hang = feature_presets.hang,
   },
+  status = luaotfloadstatus,
 }
 
 -------------------------------------------------------------------------------
@@ -990,7 +992,6 @@
       end
     end
   end
-  result.status = luaotfloadstatus
   return result
 end
 

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-database.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-database.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-database.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 do -- block to avoid to many local variables error
  assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
      name          = "luaotfload-database",
-     version       = "3.28",       --TAGVERSION
-     date          = "2024-02-14", --TAGDATE
+     version       = "3.29",       --TAGVERSION
+     date          = "2024-12-03", --TAGDATE
      description   = "luaotfload submodule / database",
      license       = "GPL v2.0",
      author        = "Khaled Hosny, Elie Roux, Philipp Gesang, Marcel Krüger",
@@ -122,7 +122,7 @@
 local P, lpegmatch         = lpeg.P, lpeg.match
 
 local log                      = luaotfload.log
-local logreport                = log and log.report or print -- overriden later on
+local logreport                = log and log.report or print -- overridden later on
 local report_status            = log.names_status
 local report_status_start      = log.names_status_start
 local report_status_stop       = log.names_status_stop
@@ -786,7 +786,7 @@
 
     get_font_file -- Look up the file of an entry in the mappings
     table. If the index is valid, pass on the name and subfont index
-    after verifing the existence of the resolved file. This
+    after verifying the existence of the resolved file. This
     verification differs depending the index entry’s ``location``
     field:
 
@@ -821,7 +821,7 @@
 --[[doc--
 We need to verify if the result of a cached lookup actually exists in
 the texmf or filesystem. Again, due to the schizoprenic nature of the
-font managment we have to check both the system path and the texmf.
+font management we have to check both the system path and the texmf.
 --doc]]--
 
 local function verify_font_file (basename)
@@ -1395,7 +1395,7 @@
     for n = 1, n_fonts do
         local current    = mappings[n]
         --[[
-            This is simplistic but surpisingly fast.
+            This is simplistic but surprisingly fast.
             Matching is performed against the “fullname” field
             of a db record in preprocessed form. We then store the
             raw “fullname” at its edit distance.
@@ -1979,7 +1979,7 @@
 
     --- windows and dos
     if os_type == "windows" or os_type == "msdos" then
-        --- ms platfom specific stuff
+        --- ms platform specific stuff
         function path_normalize (path)
             path = stringgsub(path, '\\', '/')
             path = stringlower(path)

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-diagnostics.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-diagnostics.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-diagnostics.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -7,8 +7,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-diagnostics",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload-tool submodule / diagnostics",
     license       = "GPL v2.0"
 }
@@ -252,11 +252,12 @@
 
 local function init_desired_permissions ()
     local paths = config.luaotfload.paths
+    local compress_db = config.luaotfload.db.compress
     return {
         { "d", {"r","w"}, function () return caches.getwritablepath ("", "") end },
         { "d", {"r","w"}, paths.prefix },
-        { "f", {"r","w"}, paths.index_path_lua .. ".gz" },
-        { "f", {"r","w"}, paths.index_path_luc },
+        { "f", {"r","w"}, paths.index_path_lua .. (compress_db and ".gz" or "") },
+        { "f", {"r","w"}, paths.index_path_luc .. (compress_db and ".gz" or "") },
         { "f", {"r","w"}, paths.lookup_path_lua },
         { "f", {"r","w"}, paths.lookup_path_luc },
     }

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-dvi.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-dvi.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-dvi.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -6,8 +6,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-dvi",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / DVI",
     license       = "GPL v2.0",
     author        = "Marcel Krüger",

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-embolden.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-embolden.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-embolden.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-embolden",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / embolden",
     license       = "GPL v2.0",
     author        = "Marcel Krüger"

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-fallback.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-fallback.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-fallback.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") {
     name          = "luaotfload-fallback",
-    version       = "3.28",     --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",     --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / fallback",
     license       = "GPL v2.0",
     author        = "Marcel Krüger"
@@ -103,7 +103,7 @@
 end
 
 function luaotfload.add_fallback(name, fonts)
-  define_font = define_font or luaotfload.define_font -- Lazy loading because this file get's loaded before define_font is defined
+  define_font = define_font or luaotfload.define_font -- Lazy loading because this file gets loaded before define_font is defined
   if fonts == nil then
     fonts = name
     name = #fallback_table_fontnames + 1

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-features.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-features.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-features.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-features",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / features",
     license       = "GPL v2.0",
     author        = "Hans Hagen, Khaled Hosny, Elie Roux, Philipp Gesang, Marcel Krüger",
@@ -40,7 +40,7 @@
 
 local config            = config or { luaotfload = { run = { } } }
 
-local as_script         = config.luaotfload.run.live
+local as_script         = not config.luaotfload.run.live
 local normalize
 
 if as_script then
@@ -927,6 +927,20 @@
     },
 }
 
+local function unset_designsize(tfmdata)
+    tfmdata.designsize = 0
+end
+fonts.constructors.features.otf.register {
+    name = 'no_designsize',
+    description = 'Set designsize to zero to ensure round-tripping in \\fontsize',
+    default = true,
+    manipulators = {
+        base = unset_designsize,
+        node = unset_designsize,
+        plug = unset_designsize,
+    },
+}
+
 return function ()
     if not fonts and fonts.handlers then
         report ("log", 0, "features",

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-filelist.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-filelist.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-filelist.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -6,8 +6,8 @@
 
 if luaotfload_module then luaotfload_module {
     name          = "luaotfload-filelist",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / filelist",
     license       = "GPL v2.0"
 } end
@@ -259,9 +259,7 @@
     { name = "characters"        ,kind = kind_generated, ext =".lua", gitdir=gitdirgen, texdir=texdirtex, gitpref = "luaotfload-", script="mkcharacter" },
     { name = "glyphlist"         ,kind = kind_generated, ext =".lua", gitdir=gitdirgen, texdir=texdirtex, gitpref = "luaotfload-", script="mkglyphlist" },
     { name = "status"            ,kind = kind_generated, ext =".lua", gitdir=gitdirgen, texdir=texdirtex, gitpref = "luaotfload-", script="mkstatus",mkstatus="ignore" },
-     
 
-
 -- scripts
     { name = "mkimport"       ,kind = kind_script, gitdir = gitdirscr, gitpref = "", ext=""},
     { name = "mkglyphlist"   ,kind = kind_script, gitdir = gitdirscr, gitpref = "", ext=""}, 
@@ -388,7 +386,6 @@
 end   
 
 -- core and lib  lua-files
-
 function luaotfload.filelist.selectlolsrcluaentries (filetable)
  local result = {}  
  for i,v in ipairs (filetable) do
@@ -399,10 +396,7 @@
  return result
 end   
 
-
-
--- luaoftload generated
-
+-- luaotfload generated
 function luaotfload.filelist.selectlolgeneentries (filetable)
  local result = {}  
  for i,v in ipairs (filetable) do
@@ -413,8 +407,6 @@
  return result
 end   
 
-
-
 -- scripts
 function luaotfload.filelist.selectlolscrentries ( filetable )
   local result = {}
@@ -425,9 +417,3 @@
   end
   return result
 end
-
-
-
-
-
-

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-glyphlist.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-glyphlist.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-glyphlist.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -1,8 +1,8 @@
 if luaotfload_module then
   luaotfload_module {
     name          = "luaotfload-glyphlist",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / autogenerated glyphlist",
     copyright   = "derived from https://raw.githubusercontent.com/adobe-type-tools/agl-aglfn/master/glyphlist.txt",
     original    = "Adobe Glyph List, version 2.0, September 20, 2002",

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-define.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-define.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-define.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 do -- block to avoid to many local variables error
  assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
      name          = "luaotfload-harf-define",
-     version       = "3.28",       --TAGVERSION
-     date          = "2024-02-14", --TAGDATE
+     version       = "3.29",       --TAGVERSION
+     date          = "2024-12-03", --TAGDATE
      description   = "luaotfload submodule / HarfBuzz font loading",
      license       = "GPL v2.0",
      author        = "Khaled Hosny, Marcel Krüger",
@@ -18,6 +18,8 @@
 local stringlower = string.lower
 local stringupper = string.upper
 local gsub = string.gsub
+local find = string.find
+local format = string.format
 
 local hb = luaotfload.harfbuzz
 local scriptlang_to_harfbuzz = require'luaotfload-scripts'.to_harfbuzz
@@ -56,7 +58,8 @@
   --   local first, second = string.byte(s)
   --   return (first << 8) | second
   -- end
-  local factor = 6578.176 -- =803/125*2^10=7227/7200/10*2^16
+  -- local factor = 6578.176 -- =803/125*2^10=7227/7200/10*2^16
+  local factor = 6553.6 -- =2^16/10
   function get_designsize(face)
     local buf = face:get_table(gpostag):get_data()
     if #buf == 0 then return 655360 end
@@ -79,7 +82,6 @@
 local keyhash do
   local formatstring = string.rep('%02x', 256/8)
   local sha256 = sha2.digest256
-  local format = string.format
   local byte = string.byte
   keyhash = setmetatable({}, {__index = function(t, k)
     local h = format(formatstring, byte(sha256(k), 1, -1))
@@ -105,7 +107,7 @@
 local function loadfont(spec)
   local path, sub = spec.resolved, spec.sub or 1
 
-  local key = string.format("%s:%d:%s", path, sub, instance)
+  local key = format("%s:%d:%s", path, sub, instance)
 
   local attributes = lfs.attributes(path)
   if not attributes then return end
@@ -426,8 +428,13 @@
     end
   end
 
+  local texname = spec.specification
+  if find(texname, ' ') then
+    texname = format('"%s"', texname) -- Not %q since we do not want escape sequences inside the string
+  end
+
   local tfmdata = {
-    name = spec.specification,
+    name = texname,
     filename = 'harfloaded:' .. spec.resolved,
     subfont = spec.sub or 1,
     designsize = data.designsize,

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-plug.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-plug.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-plug.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -4,8 +4,8 @@
 -----------------------------------------------------------------------
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") {
   name          = "luaotfload-harf-plug",
-  version       = "3.28",       --TAGVERSION
-  date          = "2024-02-14", --TAGDATE
+  version       = "3.29",       --TAGVERSION
+  date          = "2024-12-03", --TAGDATE
   description   = "luaotfload submodule / HarfBuzz shaping",
   license       = "GPL v2.0",
   author        = "Khaled Hosny, Marcel Krüger",
@@ -912,7 +912,7 @@
               -- fonts, so we don't want them to reach the backend as it will cause
               -- a fatal error. We use `nullfont` instead.  That is a hack, but I
               -- think it is good enough for now. We could make the glyph virtual
-              -- with empty commands suh that LuaTeX ignores it, but we still want
+              -- with empty commands such that LuaTeX ignores it, but we still want
               -- a missing glyph warning.
               -- We insert the glyph node and move on, no further work is needed.
               setfont(node, 0)

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-var-cff2.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-var-cff2.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-var-cff2.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 do
  assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
      name          = "luaotfload-harf-var-cff2",
-     version       = "3.28",       --TAGVERSION
-     date          = "2024-02-14", --TAGDATE
+     version       = "3.29",       --TAGVERSION
+     date          = "2024-12-03", --TAGDATE
      description   = "luaotfload submodule / CFF2 table processing",
      license       = "GPL v2.0",
      author        = "Marcel Krüger",
@@ -85,7 +85,7 @@
 
 local function do_blend(result, vstore)
   if not vstore then
-    error'blend operator only allowed in Private disctionary of variable fonts'
+    error'blend operator only allowed in Private dictionary of variable fonts'
   end
   local vsindex = (result.vsindex or 0) + 1
   local factors = vstore[vsindex]

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-var-t2-writer.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-var-t2-writer.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-var-t2-writer.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 do
  assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
      name          = "luaotfload-harf-var-t2-writer",
-     version       = "3.28",       --TAGVERSION
-     date          = "2024-02-14", --TAGDATE
+     version       = "3.29",       --TAGVERSION
+     date          = "2024-12-03", --TAGDATE
      description   = "luaotfload submodule / Type 2 charstring writer",
      license       = "GPL v2.0",
      author        = "Marcel Krüger",

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-var-ttf.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-var-ttf.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-harf-var-ttf.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 do
  assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
      name          = "luaotfload-harf-var-ttf",
-     version       = "3.28",       --TAGVERSION
-     date          = "2024-02-14", --TAGDATE
+     version       = "3.29",       --TAGVERSION
+     date          = "2024-12-03", --TAGDATE
      description   = "luaotfload submodule / gvar table processing",
      license       = "GPL v2.0",
      author        = "Marcel Krüger",
@@ -238,7 +238,7 @@
         end
         last = last + value
         point.y = last
-        point.flags = flags & 0xC1 -- Discard all flags we aready used
+        point.flags = flags & 0xC1 -- Discard all flags we already used
       end
       -- assert (i == total_points)
     end

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-init.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-init.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-init.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -7,8 +7,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") {
     name          = "luaotfload-init",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / initialization",
     license       = "GPL v2.0"
 }
@@ -206,7 +206,7 @@
     end
   end
   logreport("both", 0, "init", "A directory name has been passed as \z
-    fontloader name but this directory does not acutally seem to contain \z
+    fontloader name but this directory does not actually seem to contain \z
     a font loader. I will try to interpret your fontloader name in another \z
     way for now, but please fix your settings.")
   return false

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-letterspace.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-letterspace.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-letterspace.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-letterspace",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / letterspacing",
     license       = "GPL v2.0",
     copyright     = "PRAGMA ADE / ConTeXt Development Team",
@@ -352,7 +352,6 @@
             then
               -- keep
             else
-              setsubtype (prev, userkern_code)
               local prev_kern = getkern(prev)
               prev_kern = prev_kern + krn
               setkern (prev, prev_kern)

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-loaders.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-loaders.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-loaders.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -8,8 +8,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-loaders",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / callback handling",
     license       = "GPL v2.0"
 }

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-log.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-log.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-log.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -6,8 +6,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-log",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / logging",
     license       = "GPL v2.0",
     author        = "Khaled Hosny, Elie Roux, Philipp Gesang",

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-multiscript.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-notdef.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-notdef.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-notdef",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / notdef",
     license       = "GPL v2.0",
     author        = "Marcel Krüger"

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-parsers.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-parsers.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-parsers.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -7,8 +7,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-parsers",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / parsers",
     license       = "GPL v2.0"
 }
@@ -182,7 +182,7 @@
 
 --[[doc--
       fonts_conf_scanner() handles configuration files.
-      It is called on an abolute path to a config file (e.g.
+      It is called on an absolute path to a config file (e.g.
       /home/luser/.config/fontconfig/fonts.conf) and returns a list
       of the nodes it managed to extract from the file.
 --doc]]--
@@ -431,7 +431,7 @@
     where
       <csname> is the control sequence that activates the font
       <prefix> is either “file” or “name”, determining the lookup
-      <identifer> is either a file name (no path) or a font
+      <identifier> is either a file name (no path) or a font
                   name, depending on the lookup
       <features> is a list of switches or options, separated by
                  semicolons or commas; a switch is of the form “+” foo

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-resolvers.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-resolvers.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-resolvers.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -11,8 +11,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-resolvers",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / resolvers",
     license       = "GPL v2.0"
 }
@@ -57,7 +57,7 @@
     this is still short of the goal »\emphasis{it just works!}«.
     When building the font database \identifier{luaotfload} scans
     system font directories anyways, so we already have all the
-    information for looking sytem fonts.
+    information for looking system fonts.
     With the release version 2.2 the file names are indexed in the
     database as well and we are ready to resolve \verb|file:| lookups
     this way.

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-scripts.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-scripts.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-scripts.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-script",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / Script helpers",
     license       = "CC0 1.0 Universal",
     author        = "Marcel Krüger"

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-status.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-status.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-status.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -55,45 +55,40 @@
   { "fontloader-data-con.lua", "b4ab51aaeab872d86d827f3e216bf05e" },
   { "fontloader-reference.lua", "23d03b682af6417aa08995f2ec10de22" },
   { "fontloader-basics-gen.lua", "578c251c496bed783075709e94c2be26" },
-  { "mktests", "918cb50be9ee8bd645ac1a27dc501e8c" },
-  { "mkstatus", "855ec00d090bd8949a1e2d2a59ca553e" },
-  { "mkcharacters", "bfca0e96e1e351afe7077502f9595af9" },
-  { "mkglyphlist", "7a8a8fdc0eac7fac2f13ec8f4e8e7aa9" },
-  { "mkimport", "7d62f1042e548f8b9368f26b9ba4be5c" },
-  { "luaotfload-glyphlist.lua", "61c0df805e753d4408972d93c1f4fef4" },
+  { "luaotfload-glyphlist.lua", "beb741fb48fc25ceb0edfed023c06a94" },
   { "luaotfload-characters.lua", "76415ca3ede312cad6e09038323489ae" },
-  { "luaotfload-dvi.lua", "8d3f9adeaf8896eb94baf4f4a7cb72a4" },
-  { "luaotfload-tounicode.lua", "245271ce518c136c96f22fee6cb810ab" },
-  { "luaotfload-unicode.lua", "cebc6454abe34f2fe1c1248f8b2453da" },
-  { "luaotfload-resolvers.lua", "0f87b7c297120189ddbd31f6ee324a9f" },
-  { "luaotfload-parsers.lua", "73f67f95af947fe741c931e6f60b84cb" },
-  { "luaotfload-fallback.lua", "3b1569703b22fabe9661f2188fa0dbd3" },
-  { "luaotfload-szss.lua", "bdf184e24947478dc89307adf866a3ca" },
-  { "luaotfload-scripts.lua", "2026f40b86c3e93eba401524424e71d9" },
-  { "luaotfload-multiscript.lua", "1415dc53c2ad56f6dc892212090d7c03" },
-  { "luaotfload-loaders.lua", "80907f5cf87e2d5f946936a1ef08b6a8" },
-  { "luaotfload-harf-plug.lua", "201bbdd109fa1f0b02068e59f2f5384d" },
-  { "luaotfload-harf-define.lua", "f1319af7f3837fbda6db470b77627c71" },
-  { "luaotfload-notdef.lua", "920854a37e695604457cb1fcad35a814" },
-  { "luaotfload-embolden.lua", "6b15c8ae9e49cfb4a5e319aadf1ef3ac" },
-  { "luaotfload-letterspace.lua", "45fe7d691be75f6ef7f0c058c40113d9" },
-  { "luaotfload-features.lua", "756bc857a0d63bf1a6abbd1406e85844" },
-  { "luaotfload-database.lua", "0e2f26fead21ffdb36f36a5090220f8d" },
-  { "luaotfload-configuration.lua", "0abab568ba9c0082c9ad3e1b75897d49" },
-  { "luaotfload-colors.lua", "cda35651d19ec5ae24d18f3b0e1cfeec" },
-  { "luaotfload-auxiliary.lua", "6dbe1a2a3f36cf57845e54c1927ccfee" },
-  { "luaotfload-filelist.lua", "bd805bc5b92346005cde05679a4db421" },
-  { "luaotfload-tool.lua", "244ec7b1febf40d9e153e7aab7ad7237" },
-  { "luaotfload-diagnostics.lua", "8a51337bd7dcaf772ced0c16d13654cc" },
-  { "luaotfload-log.lua", "b0cd5d77653fae19eceb1c1f195d9b77" },
-  { "luaotfload-init.lua", "5808f9c69b6a266fef8b923aefaecdc3" },
+  { "luaotfload-dvi.lua", "c21eaeeaf37d6fb5b01709a36fbc9c43" },
+  { "luaotfload-tounicode.lua", "21fe79d2526f3c3d789a9cc0366347ab" },
+  { "luaotfload-unicode.lua", "4272855a25780b80472f3b58edd95e33" },
+  { "luaotfload-resolvers.lua", "4f8521dc226d08512950d1d5e8aab8c2" },
+  { "luaotfload-parsers.lua", "2e9a5d75a9ee0e5f9a1e1c8323cd2de0" },
+  { "luaotfload-fallback.lua", "e05de4261a8752342848719813588180" },
+  { "luaotfload-szss.lua", "e251628fef2f987a01578e9cc4c82588" },
+  { "luaotfload-scripts.lua", "6327dd2af89cf4683693118b025b3eaa" },
+  { "luaotfload-multiscript.lua", "43be714858bc37c09930d53a42882afa" },
+  { "luaotfload-loaders.lua", "2f1994b70766eb36ef058a1c9b6b68b6" },
+  { "luaotfload-harf-plug.lua", "6257d6011bc38cd0b21efba6f7385ef4" },
+  { "luaotfload-harf-define.lua", "bfd8d8d2badb2ccd8a4a06fcbfafa74c" },
+  { "luaotfload-notdef.lua", "fa3fca3ed4bd42155506aa25b43e28e8" },
+  { "luaotfload-embolden.lua", "805f2fb9deea6465e6a234e8f8484b3c" },
+  { "luaotfload-letterspace.lua", "74844a364041657273a550d05b195eaa" },
+  { "luaotfload-features.lua", "53438c93b9fd5b6ed6dcf18f6489416a" },
+  { "luaotfload-database.lua", "54d2b1150ded4b0a3a6b2f6f172be9aa" },
+  { "luaotfload-configuration.lua", "c077eeb67481e5156cc70d6f5731637b" },
+  { "luaotfload-colors.lua", "4e7012beae70afc8513d724e94d889f6" },
+  { "luaotfload-auxiliary.lua", "08a4e0dae8c3826067aa833dde7ed899" },
+  { "luaotfload-filelist.lua", "b2172cbee288902cc4944c0160bc9a02" },
+  { "luaotfload-tool.lua", "e4be97c97c71d3f0d55b02188453df85" },
+  { "luaotfload-diagnostics.lua", "664bb25ab022856ba173de7cc058848b" },
+  { "luaotfload-log.lua", "743199ad7313baa02f88c938b567db1a" },
+  { "luaotfload-init.lua", "f30eaefe7631651281cecba90b912e64" },
   { "luaotfload-main.lua", "b19c9cc34cf1d676c39f872cfb41aef6" },
  },
  ["notes"]={
   ["committer"]="Marcel Fabian Krüger <tex at 2krueger.de>",
-  ["description"]="v3.28/2024-02-14",
+  ["description"]="v3.29/2024-12-03",
   ["loader"]="fontloader-2023-12-28.lua",
-  ["revision"]="73dac18445938c6c54118045944817c4e8c59a1c",
-  ["timestamp"]="2024-02-28 06:18:10 +0100",
+  ["revision"]="48139bd3b29cd45baf567b5f35b98ad2b9d7bccb",
+  ["timestamp"]="2025-02-26 22:33:31 +0100",
  },
 }
\ No newline at end of file

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-suppress.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-suppress.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-suppress.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-suppress",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / suppress",
     license       = "GPL v2.0",
     author        = "Marcel Krüger"

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-szss.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-szss.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-szss.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-szss",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / Special feature handling",
     license       = "GPL v2.0",
     author        = "Marcel Krüger"

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-tounicode.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-tounicode.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-tounicode.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
     name          = "luaotfload-tounicode",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / tounicode",
     license       = "GPL v2.0",
     author        = "Hans Hagen, Khaled Hosny, Elie Roux, Philipp Gesang, Marcel Krüger",
@@ -14,7 +14,7 @@
 }
 
 local overloads = {
-  -- rougly based on texglyphlist-g2u.txt
+  -- roughly based on texglyphlist-g2u.txt
 
   -- ff = { unicode = {0x0066, 0x0066} },
   -- ffi = { unicode = {0x0066, 0x0066, 0x0069} },

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-unicode.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-unicode.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-unicode.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") {
     name          = "luaotfload-unicode",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / Unicode helpers",
     license       = "CC0 1.0 Universal",
     author        = "Marcel Krüger"
@@ -239,7 +239,7 @@
 
 -- Special handling for Eastern Armenian based on Unicode document L2/20-143.
 uppercase[0x0587]['hy'] = { _ = { 0x0535, 0x054E } }
--- Resore Unicode behavior. This entry is redundant, but we have to be aware of it
+-- Restore Unicode behavior. This entry is redundant, but we have to be aware of it
 -- if we later start to ignore unknown private use tags
 uppercase[0x0587]['hy-x-yiwn'] = { _ = uppercase[0x0587]._ }
 

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload.lua
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -20,8 +20,8 @@
 -- version number is used below!
 local ProvidesLuaModule = { 
     name          = "luaotfload",
-    version       = "3.28",       --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",       --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "Lua based OpenType font support",
     author        = authors,
     copyright     = authors,
@@ -118,7 +118,7 @@
     \identifier{luatexbase} when this file is processed. In some cases
     it is possible to trick it by putting dummies into place and
     restoring the behavior from \identifier{luatexbase} after
-    initilization. Other cases such as attribute allocation require
+    initialization. Other cases such as attribute allocation require
     that we hook the functionality from \identifier{luatexbase} into
     locations where they normally wouldn’t be.
 
@@ -244,7 +244,7 @@
             modpath = file.join (path, modname)
         else
             luaotfload.log.report ("both", 0, "load",
-                                   "Non-existant path %q specified, ignoring.",
+                                   "Non-existent path %q specified, ignoring.",
                                    path)
         end
     end

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload.sty
===================================================================
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload.sty	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload.sty	2025-02-27 20:11:38 UTC (rev 74324)
@@ -39,7 +39,7 @@
 \fi
 \ifdefined\ProvidesPackage
   \ProvidesPackage{luaotfload}%
-    [2024/02/14 v3.28  OpenType layout system]
+    [2024/12/03 v3.29  OpenType layout system]
 \fi
 \directlua{
   if xpcall(function ()%



More information about the tex-live-commits mailing list.
--- trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-multiscript.lua	2025-02-27 19:31:43 UTC (rev 74323)
+++ trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-multiscript.lua	2025-02-27 20:11:38 UTC (rev 74324)
@@ -5,8 +5,8 @@
 
 assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") {
     name          = "luaotfload-multiscript",
-    version       = "3.28",     --TAGVERSION
-    date          = "2024-02-14", --TAGDATE
+    version       = "3.29",     --TAGVERSION
+    date          = "2024-12-03", --TAGDATE
     description   = "luaotfload submodule / multiscript",
     license       = "GPL v2.0",
     author        = "Marcel Krüger"
@@ -214,7 +214,7 @@
 end
 
 local function makecombifont(tfmdata, _, additional_scripts)
-  define_font = define_font or luaotfload.define_font -- Lazy loading because this file get's loaded before define_font is defined
+  define_font = define_font or luaotfload.define_font -- Lazy loading because this file gets loaded before define_font is defined
   local has_auto
   additional_scripts = tostring(additional_scripts)
   if additional_scripts:sub(1, 5) == "auto+" then
@@ -230,7 +230,7 @@
     for k, v in next, t do if type(k) == "string" then
       local l = string.lower(k)
       if lower_t[l] ~= nil and lower_t[l] ~= v then
-        error(string.format("Inconsistant multiscript table %q for script %s", additional_scripts, l))
+        error(string.format("Inconsistent multiscript table %q for script %s", additional_scripts, l))
       end
       lower_t[l] = v
     end end
@@ -287,7 +287,7 @@
           additional_scripts[iso_script] = spec.specification .. ';-multiscript;script=' .. script
           ---- FIXME: IMHO the following which just modiefies the spec
           --   would be nicer, but it breaks font patching callbacks
           --   (except if we ignore them, but that would be inconsistant to
           --    other fonts)
           -- local new_raw_features = {}
           -- local new_features = { raw = new_raw_features, normal = new_raw_features }
@@ -287,7 +287,7 @@
           ---- FIXME: IMHO the following which just modiefies the spec
           --   would be nicer, but it breaks font patching callbacks
-          --   (except if we ignore them, but that would be inconsistant to
+          --   (except if we ignore them, but that would be inconsistent to
           --    other fonts)
           -- local new_raw_features = {}

Modified: trunk/Master/texmf-dist/tex/luatex/luaotfload/luaotfload-notdef.lua
===================================================================